==> haskell-diff-0.5-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Diff
version:              0.5
visibility:           public
id:                   Diff-0.5-FnuvpTjZ7zP8E0VsBqTjvq
key:                  Diff-0.5-FnuvpTjZ7zP8E0VsBqTjvq
license:              BSD-3-Clause
maintainer:           David Fox <dsf@seereason.com>
author:               Sterling Clover
synopsis:             O(ND) diff algorithm in haskell.
description:
    Implementation of the standard diff algorithm, and utilities for pretty printing.

category:             Algorithms
abi:                  a50fb3d551dd0424984179d8140d0398
exposed:              True
exposed-modules:
    Data.Algorithm.Diff Data.Algorithm.DiffContext
    Data.Algorithm.DiffOutput

import-dirs:          /usr/lib/ghc-9.6.6/site-local/Diff-0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/Diff-0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/Diff-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-diff
hs-libraries:         HSDiff-0.5-FnuvpTjZ7zP8E0VsBqTjvq
depends:              array-0.5.6.0 base-4.18.2.1 pretty-1.1.3.6
haddock-interfaces:   /usr/share/doc/haskell-diff/html/Diff.haddock
haddock-html:         /usr/share/doc/haskell-diff/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-diff-0.5-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Diff
version:              0.5
visibility:           public
id:                   Diff-0.5-ITRWFAaKGpZDrg9OMgbtjy
key:                  Diff-0.5-ITRWFAaKGpZDrg9OMgbtjy
license:              BSD-3-Clause
maintainer:           David Fox <dsf@seereason.com>
author:               Sterling Clover
synopsis:             O(ND) diff algorithm in haskell.
description:
    Implementation of the standard diff algorithm, and utilities for pretty printing.

category:             Algorithms
abi:                  bc9a1cb3c56f56d28bc0f123118a7d93
exposed:              True
exposed-modules:
    Data.Algorithm.Diff Data.Algorithm.DiffContext
    Data.Algorithm.DiffOutput

import-dirs:          /usr/lib/ghc-9.6.6/site-local/Diff-0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/Diff-0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/Diff-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-diff
hs-libraries:         HSDiff-0.5-ITRWFAaKGpZDrg9OMgbtjy
depends:              array-0.5.6.0 base-4.18.2.1 pretty-1.1.3.6
haddock-interfaces:   /usr/share/doc/haskell-diff/html/Diff.haddock
haddock-html:         /usr/share/doc/haskell-diff/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
